#!/bin/bash

set -u

crtscript=$(readlink -e "$0")
basedir="${crtscript%/*}"
network="labvms"
labdirs=($(find "${basedir}" -type d -name "lab-*"))
ipprefix=192.168.100

sudo virsh net-define "/usr/share/libvirt/networks/${network}.xml" 2>/dev/null
sudo virsh net-autostart "${network}" 2>/dev/null
sudo virsh net-start "${network}" 2>/dev/null

sudo sysctl net.ipv4.ip_forward=1

for labdir in "${labdirs[@]}"; do
    dir=$(readlink -e "${labdir}")
    source "${dir}/config"
    ip="${ipprefix}.${hostip}"

    sudo virsh net-update "${network}" add ip-dhcp-host \
        "<host mac='${macaddr}' name='${vmname}' ip='${ip}'/>" 2>/dev/null

    disks=($(find "${dir}" -maxdepth 1 -type f -name '*.qcow2' | sort -V))
    disk_args=$(printf -- "--disk path='%s',format=qcow2 " "${disks[@]}")

    for disk in "${disks[@]}"; do
        qemu-img snapshot "${disk}" -d new
        qemu-img resize "${disk}" 16G
        qemu-img snapshot "${disk}" -c resized
    done

    sudo virt-install --name "${vmname}" --hvm --os-variant generic --ram "${memory}"       \
        --cpu host --vcpus "cores=${cores}" --network network="${network}",mac="${macaddr}" \
        --graphics vnc,listen=127.0.0.1 --noautoconsole --import --virt-type kvm ${disk_args}
done
